| Title: | Regression Calibration for Classical Measurement Error |
|---|---|
| Description: | Contains functions to get calibrated latent trait estimates under assumption of classical measurement error. |
| Authors: | James Uanhoro [aut, cre], Nivedita Bhaktha [ctb] |
| Maintainer: | James Uanhoro <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.1.9002 |
| Built: | 2026-05-18 09:58:15 UTC |
| Source: | https://github.com/jamesuanhoro/rccme |
ESTRESS data
estressestress
estressA data frame with 7 variables, 262 cases:
Company Tenure
Economic stress
Depressed affect
Withdrawal intentions
Male (1) or Female (0)
age
Entrepreneurial self efficacy
Pollack, J., VanEpps, E. M., & Hayes, A. F. (2012). The moderating role of social ties on entrepreneurs' depressed affect and withdrawal intentions in response to economic stress. Journal of Organizational Behavior, 33, 789-810.
Hayes, A. (2017). Introduction to mediation, moderation, and conditional process analysis: A regression-based approach (2nd edn, p. 692). Guilford Press.
Moon K (2023). processR: Implementation of the 'PROCESS' Macro. R package version 0.2.8, commit c6c817b5b716f2615b9814cd5022aef1cbc5c09d, https://github.com/cardiomoon/processR.
Protest data
protestprotest
protestA data frame with 6 variables, 129 cases:
subject number
experimental condition, 0 = no protest, 1 = individual protest, 2 = group protest
perceived pervasiveness of sex discrimination. Means of an 8 item Modern Sexism Scale
anger toward the attorney. "I feel angry towards Catherine"
liking of the attorney. Mean rating of 6 liking ratings of the target
appropriateness of response. Mean of four items of appropriateness of the target's response
Garcia, D. M., Schmitt, M. T., Branscombe, N. R., & Ellemers, N. (2010). Women’s reactions to ingroup members who protest discriminatory treatment: The importance of beliefs about inequality and response appropriateness. European Journal of Social Psychology, 40(5), 733–745. https://doi.org/10.1002/ejsp.644
Hayes, A. (2017). Introduction to mediation, moderation, and conditional process analysis: A regression-based approach (2nd edn, p. 692). Guilford Press.
Moon K (2023). processR: Implementation of the 'PROCESS' Macro. R package version 0.2.8, commit c6c817b5b716f2615b9814cd5022aef1cbc5c09d, https://github.com/cardiomoon/processR.
Calibrate scores under measurement error
rccme_calib_me( w_mat, rel_vec = NULL, w_se_vec = NULL, w_se_mat = NULL, z_mat = matrix(0, nrow = nrow(w_mat), ncol = 0), rescale = TRUE, standard = FALSE )rccme_calib_me( w_mat, rel_vec = NULL, w_se_vec = NULL, w_se_mat = NULL, z_mat = matrix(0, nrow = nrow(w_mat), ncol = 0), rescale = TRUE, standard = FALSE )
w_mat |
(matrix) a matrix of trait estimates for n respondents on p latent variables |
rel_vec |
(vector) a vector of marginal reliability for p latent variables |
w_se_vec |
(vector) a vector of standard errors of measurement for p latent variables |
w_se_mat |
(matrix) a matrix of trait estimates standard-errors for n respondents on p latent variables |
z_mat |
(matrix) a matrix of error-free covariates for n respondents and q covariates |
rescale |
(logical) Should the trait estimates and their standard errors be re-scaled? Default is TRUE. The variables are rescaled under the assumption that the trait estimates were not conditioned on any background variables and that the marginal variance of the latent trait is 1. This is true for standardised latent variables in CFA or the default prior variance assumption of 1 in IRT score estimates. This rescaling ensures the trait coefficients are correct for the standardised traits. |
standard |
(logical) Only relevant when passing reliability. If TRUE, attempt to return the standardised version of the calibrated scores If FALSE (default), do not attempt standardisation. |
Calibrated trait estimates.